@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2005 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -11,6 +11,9 @@
 #define PREPROCESSOR_H
 
 #include <IceUtil/Config.h>
+#ifdef __BCPLUSPLUS__
+#  include <stdio.h>
+#endif
 
 #ifndef SLICE_API
 #   ifdef SLICE_API_EXPORTS
@@ -39,6 +42,9 @@ public:
     
     std::string getBaseName();
 
+    static std::string addQuotes(const std::string&);
+    static std::string normalizeIncludePath(const std::string&);
+
 private:
     
     bool checkInputFile();
