@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 2.0.  */
+/* A Bison parser, made by GNU Bison 1.875c.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 27 "cexp.y"
+#line 26 "cexp.y"
 
 #include "config.h"
 #include <setjmp.h>
@@ -306,6 +306,25 @@ static void integer_overflow PROTO((void));
 #define SIGNED (~0)
 #define UNSIGNED 0
 
+//
+// Required to allow the code to compile with VC 8 with bison 2.1.
+//
+#if defined(_MSC_VER) && _MSC_VER == 1400
+#   define __STDC__
+#   define YYMALLOC
+#   define YYFREE
+#endif
+
+//
+// Required to allow the code to compile with VC 6 and VC 71 with
+// bison 2.3.
+//
+#if defined(_MSC_VER) && _MSC_VER < 1400
+#   define YYMALLOC malloc
+#   define YYFREE free
+#endif
+
+
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -321,14 +340,14 @@ static void integer_overflow PROTO((void));
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 247 "cexp.y"
+#line 265 "cexp.y"
 typedef union YYSTYPE {
   struct constant {HOST_WIDE_INT value; int signedp;} integer;
   struct name {U_CHAR *address; int length;} name;
   struct arglist *keywords;
 } YYSTYPE;
-/* Line 190 of yacc.c.  */
-#line 332 "cexp.c"
+/* Line 191 of yacc.c.  */
+#line 351 "cexp.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -339,8 +358,8 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 213 of yacc.c.  */
-#line 344 "cexp.c"
+/* Line 214 of yacc.c.  */
+#line 363 "cexp.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -355,10 +374,14 @@ typedef union YYSTYPE {
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
+#   define YYSTACK_ALLOC alloca
+#  endif
+# else
+#  if defined (alloca) || defined (_ALLOCA_H)
+#   define YYSTACK_ALLOC alloca
+#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
-#   else
-#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -384,7 +407,7 @@ typedef union YYSTYPE {
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short int yyss;
+  short yyss;
   YYSTYPE yyvs;
   };
 
@@ -394,7 +417,7 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
+     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
@@ -436,7 +459,7 @@ union yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char yysigned_char;
 #else
-   typedef short int yysigned_char;
+   typedef short yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -525,13 +548,13 @@ static const yysigned_char yyrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const unsigned short int yyrline[] =
+static const unsigned short yyrline[] =
 {
-       0,   277,   277,   287,   288,   295,   300,   303,   305,   308,
-     313,   312,   319,   324,   337,   354,   367,   373,   379,   385,
-     391,   394,   397,   404,   411,   418,   425,   428,   431,   435,
-     434,   441,   440,   447,   449,   446,   454,   456,   458,   467,
-     468,   481
+       0,   294,   294,   304,   305,   312,   317,   320,   322,   325,
+     330,   329,   336,   341,   354,   371,   384,   390,   396,   402,
+     408,   411,   414,   421,   428,   435,   442,   445,   448,   452,
+     451,   458,   457,   464,   466,   463,   471,   473,   475,   484,
+     485,   498
 };
 #endif
 
@@ -551,7 +574,7 @@ static const char *const yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short int yytoknum[] =
+static const unsigned short yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,    63,    58,    44,
      262,   263,   124,    94,    38,   264,   265,    60,    62,   266,
@@ -604,7 +627,7 @@ static const yysigned_char yydefgoto[] =
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
 #define YYPACT_NINF -63
-static const short int yypact[] =
+static const short yypact[] =
 {
       14,   -63,   -63,   -63,    14,    14,    14,    14,     5,    14,
       11,     6,    81,   -63,   -63,   -63,   -63,   -18,    33,   -63,
@@ -617,7 +640,7 @@ static const short int yypact[] =
 };
 
 /* YYPGOTO[NTERM-NUM].  */
-static const short int yypgoto[] =
+static const short yypgoto[] =
 {
      -63,   -63,   181,    -4,   -63,   -63,   -63,   -63,   -63,   -62
 };
@@ -740,53 +763,20 @@ do								\
     }								\
 while (0)
 
-
 #define YYTERROR	1
 #define YYERRCODE	256
 
+/* YYLLOC_DEFAULT -- Compute the default location (before the actions
+   are run).  */
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (N)								\
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
-    while (0)
+# define YYLLOC_DEFAULT(Current, Rhs, N)		\
+   ((Current).first_line   = (Rhs)[1].first_line,	\
+    (Current).first_column = (Rhs)[1].first_column,	\
+    (Current).last_line    = (Rhs)[N].last_line,	\
+    (Current).last_column  = (Rhs)[N].last_column)
 #endif
 
-
-/* YY_LOCATION_PRINT -- Print the location on the stream.
-   This macro was not mandated originally: define only if we know
-   we won't break user code: when these are the locations we know.  */
-
-#ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-              (Loc).first_line, (Loc).first_column,	\
-              (Loc).last_line,  (Loc).last_column)
-# else
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
-#endif
-
-
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -809,13 +799,19 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
+# define YYDSYMPRINT(Args)			\
+do {						\
+  if (yydebug)					\
+    yysymprint Args;				\
+} while (0)
+
+# define YYDSYMPRINTF(Title, Token, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       yysymprint (stderr, 					\
-                  Type, Value);	\
+                  Token, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -827,12 +823,12 @@ do {								\
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short int *bottom, short int *top)
+yy_stack_print (short *bottom, short *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short int *bottom;
-    short int *top;
+    short *bottom;
+    short *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -882,7 +878,8 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
+# define YYDSYMPRINT(Args)
+# define YYDSYMPRINTF(Title, Token, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -900,6 +897,10 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
+#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
+# undef YYMAXDEPTH
+#endif
+
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -981,15 +982,15 @@ yysymprint (yyoutput, yytype, yyvaluep)
   (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
-    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
+    {
+      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
+# ifdef YYPRINT
+      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
+    }
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
-
-# ifdef YYPRINT
-  if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
   switch (yytype)
     {
       default:
@@ -1005,11 +1006,10 @@ yysymprint (yyoutput, yytype, yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
+yydestruct (int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yymsg, yytype, yyvaluep)
-    const char *yymsg;
+yydestruct (yytype, yyvaluep)
     int yytype;
     YYSTYPE *yyvaluep;
 #endif
@@ -1017,10 +1017,6 @@ yydestruct (yymsg, yytype, yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) yyvaluep;
 
-  if (!yymsg)
-    yymsg = "Deleting";
-  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
-
   switch (yytype)
     {
 
@@ -1048,10 +1044,10 @@ int yyparse ();
 
 
 
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1087,7 +1083,7 @@ yyparse ()
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
+  /* Lookahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -1099,9 +1095,9 @@ yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short int yyssa[YYINITDEPTH];
-  short int *yyss = yyssa;
-  register short int *yyssp;
+  short	yyssa[YYINITDEPTH];
+  short *yyss = yyssa;
+  register short *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
@@ -1138,9 +1134,6 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
 
-
-  yyvsp[0] = yylval;
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1166,7 +1159,7 @@ yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *yyvs1 = yyvs;
-	short int *yyss1 = yyss;
+	short *yyss1 = yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -1194,7 +1187,7 @@ yyparse ()
 	yystacksize = YYMAXDEPTH;
 
       {
-	short int *yyss1 = yyss;
+	short *yyss1 = yyss;
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
@@ -1230,18 +1223,18 @@ yyparse ()
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a look-ahead token if we need one and don't already have one.  */
+/* Read a lookahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1256,7 +1249,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
+      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1276,8 +1269,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the look-ahead token.  */
-  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
+  /* Shift the lookahead token.  */
+  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1327,324 +1320,324 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 278 "cexp.y"
+#line 295 "cexp.y"
     {
-		  expression_value = (yyvsp[0].integer).value;
+		  expression_value = yyvsp[0].integer.value;
 #ifdef TEST_EXP_READER
-		  expression_signedp = (yyvsp[0].integer).signedp;
+		  expression_signedp = yyvsp[0].integer.signedp;
 #endif
 		;}
     break;
 
   case 4:
-#line 289 "cexp.y"
+#line 306 "cexp.y"
     { if (pedantic)
 			    pedwarn ("comma operator in operand of `#if'");
-			  (yyval.integer) = (yyvsp[0].integer); ;}
+			  yyval.integer = yyvsp[0].integer; ;}
     break;
 
   case 5:
-#line 296 "cexp.y"
-    { (yyval.integer).value = - (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = (yyvsp[0].integer).signedp;
-			  if (((yyval.integer).value & (yyvsp[0].integer).value & (yyval.integer).signedp) < 0)
+#line 313 "cexp.y"
+    { yyval.integer.value = - yyvsp[0].integer.value;
+			  yyval.integer.signedp = yyvsp[0].integer.signedp;
+			  if ((yyval.integer.value & yyvsp[0].integer.value & yyval.integer.signedp) < 0)
 			    integer_overflow (); ;}
     break;
 
   case 6:
-#line 301 "cexp.y"
-    { (yyval.integer).value = ! (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = SIGNED; ;}
+#line 318 "cexp.y"
+    { yyval.integer.value = ! yyvsp[0].integer.value;
+			  yyval.integer.signedp = SIGNED; ;}
     break;
 
   case 7:
-#line 304 "cexp.y"
-    { (yyval.integer) = (yyvsp[0].integer); ;}
+#line 321 "cexp.y"
+    { yyval.integer = yyvsp[0].integer; ;}
     break;
 
   case 8:
-#line 306 "cexp.y"
-    { (yyval.integer).value = ~ (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = (yyvsp[0].integer).signedp; ;}
+#line 323 "cexp.y"
+    { yyval.integer.value = ~ yyvsp[0].integer.value;
+			  yyval.integer.signedp = yyvsp[0].integer.signedp; ;}
     break;
 
   case 9:
-#line 309 "cexp.y"
-    { (yyval.integer).value = check_assertion ((yyvsp[0].name).address, (yyvsp[0].name).length,
+#line 326 "cexp.y"
+    { yyval.integer.value = check_assertion (yyvsp[0].name.address, yyvsp[0].name.length,
 						      0, NULL_PTR);
-			  (yyval.integer).signedp = SIGNED; ;}
+			  yyval.integer.signedp = SIGNED; ;}
     break;
 
   case 10:
-#line 313 "cexp.y"
+#line 330 "cexp.y"
     { keyword_parsing = 1; ;}
     break;
 
   case 11:
-#line 315 "cexp.y"
-    { (yyval.integer).value = check_assertion ((yyvsp[-4].name).address, (yyvsp[-4].name).length,
-						      1, (yyvsp[-1].keywords));
+#line 332 "cexp.y"
+    { yyval.integer.value = check_assertion (yyvsp[-4].name.address, yyvsp[-4].name.length,
+						      1, yyvsp[-1].keywords);
 			  keyword_parsing = 0;
-			  (yyval.integer).signedp = SIGNED; ;}
+			  yyval.integer.signedp = SIGNED; ;}
     break;
 
   case 12:
-#line 320 "cexp.y"
-    { (yyval.integer) = (yyvsp[-1].integer); ;}
+#line 337 "cexp.y"
+    { yyval.integer = yyvsp[-1].integer; ;}
     break;
 
   case 13:
-#line 325 "cexp.y"
-    { (yyval.integer).signedp = (yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp;
-			  if ((yyval.integer).signedp)
+#line 342 "cexp.y"
+    { yyval.integer.signedp = yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp;
+			  if (yyval.integer.signedp)
 			    {
-			      (yyval.integer).value = (yyvsp[-2].integer).value * (yyvsp[0].integer).value;
-			      if ((yyvsp[-2].integer).value
-				  && ((yyval.integer).value / (yyvsp[-2].integer).value != (yyvsp[0].integer).value
-				      || ((yyval.integer).value & (yyvsp[-2].integer).value & (yyvsp[0].integer).value) < 0))
+			      yyval.integer.value = yyvsp[-2].integer.value * yyvsp[0].integer.value;
+			      if (yyvsp[-2].integer.value
+				  && (yyval.integer.value / yyvsp[-2].integer.value != yyvsp[0].integer.value
+				      || (yyval.integer.value & yyvsp[-2].integer.value & yyvsp[0].integer.value) < 0))
 				integer_overflow ();
 			    }
 			  else
-			    (yyval.integer).value = ((unsigned_HOST_WIDE_INT) (yyvsp[-2].integer).value
-					* (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = ((unsigned_HOST_WIDE_INT) yyvsp[-2].integer.value
+					* yyvsp[0].integer.value); ;}
     break;
 
   case 14:
-#line 338 "cexp.y"
-    { if ((yyvsp[0].integer).value == 0)
+#line 355 "cexp.y"
+    { if (yyvsp[0].integer.value == 0)
 			    {
 			      if (!skip_evaluation)
 				error ("division by zero in #if");
-			      (yyvsp[0].integer).value = 1;
+			      yyvsp[0].integer.value = 1;
 			    }
-			  (yyval.integer).signedp = (yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp;
-			  if ((yyval.integer).signedp)
+			  yyval.integer.signedp = yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp;
+			  if (yyval.integer.signedp)
 			    {
-			      (yyval.integer).value = (yyvsp[-2].integer).value / (yyvsp[0].integer).value;
-			      if (((yyval.integer).value & (yyvsp[-2].integer).value & (yyvsp[0].integer).value) < 0)
+			      yyval.integer.value = yyvsp[-2].integer.value / yyvsp[0].integer.value;
+			      if ((yyval.integer.value & yyvsp[-2].integer.value & yyvsp[0].integer.value) < 0)
 				integer_overflow ();
 			    }
 			  else
-			    (yyval.integer).value = ((unsigned_HOST_WIDE_INT) (yyvsp[-2].integer).value
-					/ (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = ((unsigned_HOST_WIDE_INT) yyvsp[-2].integer.value
+					/ yyvsp[0].integer.value); ;}
     break;
 
   case 15:
-#line 355 "cexp.y"
-    { if ((yyvsp[0].integer).value == 0)
+#line 372 "cexp.y"
+    { if (yyvsp[0].integer.value == 0)
 			    {
 			      if (!skip_evaluation)
 				error ("division by zero in #if");
-			      (yyvsp[0].integer).value = 1;
+			      yyvsp[0].integer.value = 1;
 			    }
-			  (yyval.integer).signedp = (yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp;
-			  if ((yyval.integer).signedp)
-			    (yyval.integer).value = (yyvsp[-2].integer).value % (yyvsp[0].integer).value;
+			  yyval.integer.signedp = yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp;
+			  if (yyval.integer.signedp)
+			    yyval.integer.value = yyvsp[-2].integer.value % yyvsp[0].integer.value;
 			  else
-			    (yyval.integer).value = ((unsigned_HOST_WIDE_INT) (yyvsp[-2].integer).value
-					% (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = ((unsigned_HOST_WIDE_INT) yyvsp[-2].integer.value
+					% yyvsp[0].integer.value); ;}
     break;
 
   case 16:
-#line 368 "cexp.y"
-    { (yyval.integer).value = (yyvsp[-2].integer).value + (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = (yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp;
-			  if (overflow_sum_sign ((yyvsp[-2].integer).value, (yyvsp[0].integer).value,
-						 (yyval.integer).value, (yyval.integer).signedp))
+#line 385 "cexp.y"
+    { yyval.integer.value = yyvsp[-2].integer.value + yyvsp[0].integer.value;
+			  yyval.integer.signedp = yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp;
+			  if (overflow_sum_sign (yyvsp[-2].integer.value, yyvsp[0].integer.value,
+						 yyval.integer.value, yyval.integer.signedp))
 			    integer_overflow (); ;}
     break;
 
   case 17:
-#line 374 "cexp.y"
-    { (yyval.integer).value = (yyvsp[-2].integer).value - (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = (yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp;
-			  if (overflow_sum_sign ((yyval.integer).value, (yyvsp[0].integer).value,
-						 (yyvsp[-2].integer).value, (yyval.integer).signedp))
+#line 391 "cexp.y"
+    { yyval.integer.value = yyvsp[-2].integer.value - yyvsp[0].integer.value;
+			  yyval.integer.signedp = yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp;
+			  if (overflow_sum_sign (yyval.integer.value, yyvsp[0].integer.value,
+						 yyvsp[-2].integer.value, yyval.integer.signedp))
 			    integer_overflow (); ;}
     break;
 
   case 18:
-#line 380 "cexp.y"
-    { (yyval.integer).signedp = (yyvsp[-2].integer).signedp;
-			  if (((yyvsp[0].integer).value & (yyvsp[0].integer).signedp) < 0)
-			    (yyval.integer).value = right_shift (&(yyvsp[-2].integer), -(yyvsp[0].integer).value);
+#line 397 "cexp.y"
+    { yyval.integer.signedp = yyvsp[-2].integer.signedp;
+			  if ((yyvsp[0].integer.value & yyvsp[0].integer.signedp) < 0)
+			    yyval.integer.value = right_shift (&yyvsp[-2].integer, -yyvsp[0].integer.value);
 			  else
-			    (yyval.integer).value = left_shift (&(yyvsp[-2].integer), (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = left_shift (&yyvsp[-2].integer, yyvsp[0].integer.value); ;}
     break;
 
   case 19:
-#line 386 "cexp.y"
-    { (yyval.integer).signedp = (yyvsp[-2].integer).signedp;
-			  if (((yyvsp[0].integer).value & (yyvsp[0].integer).signedp) < 0)
-			    (yyval.integer).value = left_shift (&(yyvsp[-2].integer), -(yyvsp[0].integer).value);
+#line 403 "cexp.y"
+    { yyval.integer.signedp = yyvsp[-2].integer.signedp;
+			  if ((yyvsp[0].integer.value & yyvsp[0].integer.signedp) < 0)
+			    yyval.integer.value = left_shift (&yyvsp[-2].integer, -yyvsp[0].integer.value);
 			  else
-			    (yyval.integer).value = right_shift (&(yyvsp[-2].integer), (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = right_shift (&yyvsp[-2].integer, yyvsp[0].integer.value); ;}
     break;
 
   case 20:
-#line 392 "cexp.y"
-    { (yyval.integer).value = ((yyvsp[-2].integer).value == (yyvsp[0].integer).value);
-			  (yyval.integer).signedp = SIGNED; ;}
+#line 409 "cexp.y"
+    { yyval.integer.value = (yyvsp[-2].integer.value == yyvsp[0].integer.value);
+			  yyval.integer.signedp = SIGNED; ;}
     break;
 
   case 21:
-#line 395 "cexp.y"
-    { (yyval.integer).value = ((yyvsp[-2].integer).value != (yyvsp[0].integer).value);
-			  (yyval.integer).signedp = SIGNED; ;}
+#line 412 "cexp.y"
+    { yyval.integer.value = (yyvsp[-2].integer.value != yyvsp[0].integer.value);
+			  yyval.integer.signedp = SIGNED; ;}
     break;
 
   case 22:
-#line 398 "cexp.y"
-    { (yyval.integer).signedp = SIGNED;
-			  if ((yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp)
-			    (yyval.integer).value = (yyvsp[-2].integer).value <= (yyvsp[0].integer).value;
+#line 415 "cexp.y"
+    { yyval.integer.signedp = SIGNED;
+			  if (yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp)
+			    yyval.integer.value = yyvsp[-2].integer.value <= yyvsp[0].integer.value;
 			  else
-			    (yyval.integer).value = ((unsigned_HOST_WIDE_INT) (yyvsp[-2].integer).value
-					<= (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = ((unsigned_HOST_WIDE_INT) yyvsp[-2].integer.value
+					<= yyvsp[0].integer.value); ;}
     break;
 
   case 23:
-#line 405 "cexp.y"
-    { (yyval.integer).signedp = SIGNED;
-			  if ((yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp)
-			    (yyval.integer).value = (yyvsp[-2].integer).value >= (yyvsp[0].integer).value;
+#line 422 "cexp.y"
+    { yyval.integer.signedp = SIGNED;
+			  if (yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp)
+			    yyval.integer.value = yyvsp[-2].integer.value >= yyvsp[0].integer.value;
 			  else
-			    (yyval.integer).value = ((unsigned_HOST_WIDE_INT) (yyvsp[-2].integer).value
-					>= (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = ((unsigned_HOST_WIDE_INT) yyvsp[-2].integer.value
+					>= yyvsp[0].integer.value); ;}
     break;
 
   case 24:
-#line 412 "cexp.y"
-    { (yyval.integer).signedp = SIGNED;
-			  if ((yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp)
-			    (yyval.integer).value = (yyvsp[-2].integer).value < (yyvsp[0].integer).value;
+#line 429 "cexp.y"
+    { yyval.integer.signedp = SIGNED;
+			  if (yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp)
+			    yyval.integer.value = yyvsp[-2].integer.value < yyvsp[0].integer.value;
 			  else
-			    (yyval.integer).value = ((unsigned_HOST_WIDE_INT) (yyvsp[-2].integer).value
-					< (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = ((unsigned_HOST_WIDE_INT) yyvsp[-2].integer.value
+					< yyvsp[0].integer.value); ;}
     break;
 
   case 25:
-#line 419 "cexp.y"
-    { (yyval.integer).signedp = SIGNED;
-			  if ((yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp)
-			    (yyval.integer).value = (yyvsp[-2].integer).value > (yyvsp[0].integer).value;
+#line 436 "cexp.y"
+    { yyval.integer.signedp = SIGNED;
+			  if (yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp)
+			    yyval.integer.value = yyvsp[-2].integer.value > yyvsp[0].integer.value;
 			  else
-			    (yyval.integer).value = ((unsigned_HOST_WIDE_INT) (yyvsp[-2].integer).value
-					> (yyvsp[0].integer).value); ;}
+			    yyval.integer.value = ((unsigned_HOST_WIDE_INT) yyvsp[-2].integer.value
+					> yyvsp[0].integer.value); ;}
     break;
 
   case 26:
-#line 426 "cexp.y"
-    { (yyval.integer).value = (yyvsp[-2].integer).value & (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = (yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp; ;}
+#line 443 "cexp.y"
+    { yyval.integer.value = yyvsp[-2].integer.value & yyvsp[0].integer.value;
+			  yyval.integer.signedp = yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp; ;}
     break;
 
   case 27:
-#line 429 "cexp.y"
-    { (yyval.integer).value = (yyvsp[-2].integer).value ^ (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = (yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp; ;}
+#line 446 "cexp.y"
+    { yyval.integer.value = yyvsp[-2].integer.value ^ yyvsp[0].integer.value;
+			  yyval.integer.signedp = yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp; ;}
     break;
 
   case 28:
-#line 432 "cexp.y"
-    { (yyval.integer).value = (yyvsp[-2].integer).value | (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = (yyvsp[-2].integer).signedp & (yyvsp[0].integer).signedp; ;}
+#line 449 "cexp.y"
+    { yyval.integer.value = yyvsp[-2].integer.value | yyvsp[0].integer.value;
+			  yyval.integer.signedp = yyvsp[-2].integer.signedp & yyvsp[0].integer.signedp; ;}
     break;
 
   case 29:
-#line 435 "cexp.y"
-    { skip_evaluation += !(yyvsp[-1].integer).value; ;}
+#line 452 "cexp.y"
+    { skip_evaluation += !yyvsp[-1].integer.value; ;}
     break;
 
   case 30:
-#line 437 "cexp.y"
-    { skip_evaluation -= !(yyvsp[-3].integer).value;
-			  (yyval.integer).value = ((yyvsp[-3].integer).value && (yyvsp[0].integer).value);
-			  (yyval.integer).signedp = SIGNED; ;}
+#line 454 "cexp.y"
+    { skip_evaluation -= !yyvsp[-3].integer.value;
+			  yyval.integer.value = (yyvsp[-3].integer.value && yyvsp[0].integer.value);
+			  yyval.integer.signedp = SIGNED; ;}
     break;
 
   case 31:
-#line 441 "cexp.y"
-    { skip_evaluation += !!(yyvsp[-1].integer).value; ;}
+#line 458 "cexp.y"
+    { skip_evaluation += !!yyvsp[-1].integer.value; ;}
     break;
 
   case 32:
-#line 443 "cexp.y"
-    { skip_evaluation -= !!(yyvsp[-3].integer).value;
-			  (yyval.integer).value = ((yyvsp[-3].integer).value || (yyvsp[0].integer).value);
-			  (yyval.integer).signedp = SIGNED; ;}
+#line 460 "cexp.y"
+    { skip_evaluation -= !!yyvsp[-3].integer.value;
+			  yyval.integer.value = (yyvsp[-3].integer.value || yyvsp[0].integer.value);
+			  yyval.integer.signedp = SIGNED; ;}
     break;
 
   case 33:
-#line 447 "cexp.y"
-    { skip_evaluation += !(yyvsp[-1].integer).value; ;}
+#line 464 "cexp.y"
+    { skip_evaluation += !yyvsp[-1].integer.value; ;}
     break;
 
   case 34:
-#line 449 "cexp.y"
-    { skip_evaluation += !!(yyvsp[-4].integer).value - !(yyvsp[-4].integer).value; ;}
+#line 466 "cexp.y"
+    { skip_evaluation += !!yyvsp[-4].integer.value - !yyvsp[-4].integer.value; ;}
     break;
 
   case 35:
-#line 451 "cexp.y"
-    { skip_evaluation -= !!(yyvsp[-6].integer).value;
-			  (yyval.integer).value = (yyvsp[-6].integer).value ? (yyvsp[-3].integer).value : (yyvsp[0].integer).value;
-			  (yyval.integer).signedp = (yyvsp[-3].integer).signedp & (yyvsp[0].integer).signedp; ;}
+#line 468 "cexp.y"
+    { skip_evaluation -= !!yyvsp[-6].integer.value;
+			  yyval.integer.value = yyvsp[-6].integer.value ? yyvsp[-3].integer.value : yyvsp[0].integer.value;
+			  yyval.integer.signedp = yyvsp[-3].integer.signedp & yyvsp[0].integer.signedp; ;}
     break;
 
   case 36:
-#line 455 "cexp.y"
-    { (yyval.integer) = yylval.integer; ;}
+#line 472 "cexp.y"
+    { yyval.integer = yylval.integer; ;}
     break;
 
   case 37:
-#line 457 "cexp.y"
-    { (yyval.integer) = yylval.integer; ;}
+#line 474 "cexp.y"
+    { yyval.integer = yylval.integer; ;}
     break;
 
   case 38:
-#line 459 "cexp.y"
+#line 476 "cexp.y"
     { if (warn_undef && !skip_evaluation)
 			    warning ("`%.*s' is not defined",
-				     (yyvsp[0].name).length, (yyvsp[0].name).address);
-			  (yyval.integer).value = 0;
-			  (yyval.integer).signedp = SIGNED; ;}
+				     yyvsp[0].name.length, yyvsp[0].name.address);
+			  yyval.integer.value = 0;
+			  yyval.integer.signedp = SIGNED; ;}
     break;
 
   case 39:
-#line 467 "cexp.y"
-    { (yyval.keywords) = 0; ;}
+#line 484 "cexp.y"
+    { yyval.keywords = 0; ;}
     break;
 
   case 40:
-#line 469 "cexp.y"
+#line 486 "cexp.y"
     { struct arglist *temp;
-			  (yyval.keywords) = (struct arglist *) xmalloc (sizeof (struct arglist));
-			  (yyval.keywords)->next = (yyvsp[-2].keywords);
-			  (yyval.keywords)->name = (U_CHAR *) "(";
-			  (yyval.keywords)->length = 1;
-			  temp = (yyval.keywords);
+			  yyval.keywords = (struct arglist *) xmalloc (sizeof (struct arglist));
+			  yyval.keywords->next = yyvsp[-2].keywords;
+			  yyval.keywords->name = (U_CHAR *) "(";
+			  yyval.keywords->length = 1;
+			  temp = yyval.keywords;
 			  while (temp != 0 && temp->next != 0)
 			    temp = temp->next;
 			  temp->next = (struct arglist *) xmalloc (sizeof (struct arglist));
-			  temp->next->next = (yyvsp[0].keywords);
+			  temp->next->next = yyvsp[0].keywords;
 			  temp->next->name = (U_CHAR *) ")";
 			  temp->next->length = 1; ;}
     break;
 
   case 41:
-#line 482 "cexp.y"
-    { (yyval.keywords) = (struct arglist *) xmalloc (sizeof (struct arglist));
-			  (yyval.keywords)->name = (yyvsp[-1].name).address;
-			  (yyval.keywords)->length = (yyvsp[-1].name).length;
-			  (yyval.keywords)->next = (yyvsp[0].keywords); ;}
+#line 499 "cexp.y"
+    { yyval.keywords = (struct arglist *) xmalloc (sizeof (struct arglist));
+			  yyval.keywords->name = yyvsp[-1].name.address;
+			  yyval.keywords->length = yyvsp[-1].name.length;
+			  yyval.keywords->next = yyvsp[0].keywords; ;}
     break;
 
 
     }
 
-/* Line 1037 of yacc.c.  */
-#line 1648 "cexp.c"
+/* Line 1000 of yacc.c.  */
+#line 1641 "cexp.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1744,7 +1737,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1754,22 +1747,23 @@ yyerrlab:
 	  if (yychar == YYEOF)
 	     for (;;)
 	       {
-
 		 YYPOPSTACK;
 		 if (yyssp == yyss)
 		   YYABORT;
-		 yydestruct ("Error: popping",
-                             yystos[*yyssp], yyvsp);
+		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+		 yydestruct (yystos[*yyssp], yyvsp);
 	       }
         }
       else
 	{
-	  yydestruct ("Error: discarding", yytoken, &yylval);
+	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+	  yydestruct (yytoken, &yylval);
 	  yychar = YYEMPTY;
+
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1786,7 +1780,7 @@ yyerrorlab:
      goto yyerrorlab;
 #endif
 
-yyvsp -= yylen;
+  yyvsp -= yylen;
   yyssp -= yylen;
   yystate = *yyssp;
   goto yyerrlab1;
@@ -1816,8 +1810,8 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-
-      yydestruct ("Error: popping", yystos[yystate], yyvsp);
+      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+      yydestruct (yystos[yystate], yyvsp);
       YYPOPSTACK;
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -1826,12 +1820,11 @@ yyerrlab1:
   if (yyn == YYFINAL)
     YYACCEPT;
 
+  YYDPRINTF ((stderr, "Shifting error token, "));
+
   *++yyvsp = yylval;
 
 
-  /* Shift the error token. */
-  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
-
   yystate = yyn;
   goto yynewstate;
 
@@ -1847,9 +1840,6 @@ yyacceptlab:
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 yyabortlab:
-  yydestruct ("Error: discarding lookahead",
-              yytoken, &yylval);
-  yychar = YYEMPTY;
   yyresult = 1;
   goto yyreturn;
 
@@ -1872,7 +1862,7 @@ yyreturn:
 }
 
 
-#line 487 "cexp.y"
+#line 504 "cexp.y"
 
 
 /* During parsing of a C expression, the pointer to the next character
